/*
 *   SPDX-FileCopyrightText: 2007-2009 Petri Damstén <damu@iki.fi>
 *   SPDX-FileCopyrightText: 2014 John Layt <jlayt@kde.org>
 *
 *   SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef LENGTH_P_H
#define LENGTH_P_H

#include "unitcategory_p.h"

namespace KUnitConversion
{
namespace Length
{
    UnitCategory makeCategory();
};

} // KUnitConversion namespace

#endif
